@@ -93,6 +93,26 @@ def remove(ctx, sliceid, actor, idtoken, refreshtoken):
         click.echo('Error occurred: {}'.format(e))
 
 
+@slices.command()
+@click.option('--email', help='User Email', required=True)
+@click.option('--actor', help='Actor Name', required=True)
+@click.option('--idtoken', default=None, help='Fabric Identity Token', required=False)
+@click.option('--refreshtoken', default=None, help='Fabric Refresh Token', required=False)
+@click.pass_context
+def removealldead(ctx, email, actor, idtoken, refreshtoken):
+    """ Removes slice for an actor
+    """
+    try:
+        idtoken = KafkaProcessorSingleton.get().start(id_token=idtoken, refresh_token=refreshtoken, ignore_tokens=True)
+        mgmt_command = ManageCommand(logger=KafkaProcessorSingleton.get().logger)
+        mgmt_command.delete_dead_slices(email=email, actor_name=actor, id_token=idtoken,
+                                        callback_topic=KafkaProcessorSingleton.get().get_callback_topic())
+        KafkaProcessorSingleton.get().stop()
+    except Exception as e:
+        # traceback.print_exc()
+        click.echo('Error occurred: {}'.format(e))
+
+
 @slices.command()
 @click.option('--actor', default=None, help='Actor Name', required=True)
 @click.option('--sliceid', default=None, help='Slice ID', required=False)
@@ -100,15 +120,19 @@ def remove(ctx, sliceid, actor, idtoken, refreshtoken):
 @click.option('--idtoken', default=None, help='Fabric Identity Token', required=False)
 @click.option('--refreshtoken', default=None, help='Fabric Refresh Token', required=False)
 @click.option('--email', default=None, help='User email', required=False)
+@click.option('--state',
+              type=click.Choice(['nascent', 'configuring', 'stableok', 'stableerror', 'modifyok', 'modifyerror',
+                                 'closing', 'dead'],
+                                case_sensitive=False), required=False)
 @click.pass_context
-def query(ctx, actor, sliceid, slicename, idtoken, refreshtoken, email):
+def query(ctx, actor, sliceid, slicename, idtoken, refreshtoken, email, state):
     """ Get slice(s) from an actor
     """
     try:
         idtoken = KafkaProcessorSingleton.get().start(id_token=idtoken, refresh_token=refreshtoken, ignore_tokens=True)
         mgmt_command = ShowCommand(logger=KafkaProcessorSingleton.get().logger)
         mgmt_command.get_slices(actor_name=actor, callback_topic=KafkaProcessorSingleton.get().get_callback_topic(),
-                                slice_id=sliceid, slice_name=slicename, id_token=idtoken, email=email)
+                                slice_id=sliceid, slice_name=slicename, id_token=idtoken, email=email, state=state)
         KafkaProcessorSingleton.get().stop()
     except Exception as e:
         # traceback.print_exc()
@@ -295,6 +319,48 @@ def query(ctx, actor, sliceid, did, state, idtoken, refreshtoken):
         click.echo('Error occurred: {}'.format(e))
 
 
+@delegations.command()
+@click.option('--did', help='Delegation Id', required=True)
+@click.option('--actor', help='Actor Name', required=True)
+@click.option('--idtoken', default=None, help='Fabric Identity Token', required=False)
+@click.option('--refreshtoken', default=None, help='Fabric Refresh Token', required=False)
+@click.pass_context
+def close(ctx, did, actor, idtoken, refreshtoken):
+    """ Closes delegation for an actor
+    """
+    try:
+        idtoken = KafkaProcessorSingleton.get().start(id_token=idtoken, refresh_token=refreshtoken, ignore_tokens=True)
+        mgmt_command = ManageCommand(logger=KafkaProcessorSingleton.get().logger)
+        mgmt_command.close_delegation(did=did, actor_name=actor,
+                                      callback_topic=KafkaProcessorSingleton.get().get_callback_topic(),
+                                      id_token=idtoken)
+        KafkaProcessorSingleton.get().stop()
+    except Exception as e:
+        # traceback.print_exc()
+        click.echo('Error occurred: {}'.format(e))
+
+
+@delegations.command()
+@click.option('--did', help='Delegation Id', required=True)
+@click.option('--actor', help='Actor Name', required=True)
+@click.option('--idtoken', default=None, help='Fabric Identity Token', required=False)
+@click.option('--refreshtoken', default=None, help='Fabric Refresh Token', required=False)
+@click.pass_context
+def remove(ctx, did, actor, idtoken, refreshtoken):
+    """ Removes sliver for an actor
+    """
+    try:
+        idtoken = KafkaProcessorSingleton.get().start(id_token=idtoken, refresh_token=refreshtoken, ignore_tokens=True)
+        mgmt_command = ManageCommand(logger=KafkaProcessorSingleton.get().logger)
+        mgmt_command.remove_delegation(did=did, actor_name=actor,
+                                       callback_topic=KafkaProcessorSingleton.get().get_callback_topic(),
+                                       id_token=idtoken)
+        KafkaProcessorSingleton.get().stop()
+    except Exception as e:
+        # traceback.print_exc()
+        click.echo('Error occurred: {}'.format(e))
+
+
 @click.group()
 @click.pass_context
 def maintenance(ctx):
